@@ -139,13 +139,11 @@ static const char copyright[] = "gl_getline:  Copyright (C) 1991, 1992, 1993, Ch
 #		define IsLocalPathDelim(c) ((c == LOCAL_PATH_DELIM) || (c == LOCAL_PATH_ALTDELIM))
 #		define UNC_PATH_PREFIX "//"
 #		define IsUNCPrefixed(s) (IsLocalPathDelim(s[0]) && IsLocalPathDelim(s[1]))
-/* _StrFindLocalPathDelim(a) -- use windows-specific function; understands '/' and '\\' */
-/* _StrRFindLocalPathDelim(a) -- use windows-specific function; understands '/' and '\\' */
 #	else
 #		define LOCAL_PATH_DELIM '/'
 #		define LOCAL_PATH_DELIM_STR "/"
-#		define _StrFindLocalPathDelim(a) strchr(a, LOCAL_PATH_DELIM)
-#		define _StrRFindLocalPathDelim(a) strrchr(a, LOCAL_PATH_DELIM)
+#		define My_StrFindLocalPathDelim(a) strchr(a, LOCAL_PATH_DELIM)
+#		define My_StrRFindLocalPathDelim(a) strrchr(a, LOCAL_PATH_DELIM)
 #		define IsLocalPathDelim(c) (c == LOCAL_PATH_DELIM)
 #	endif
 #endif
@@ -502,12 +500,14 @@ static void
 gl_putc(int c)
 {
     char   ch = (char) (unsigned char) c;
+    long rc;
 
-    (void) write(1, &ch, (write_size_t) 1);
+    rc = (long) write(1, &ch, (write_size_t) 1);
     if (ch == '\n') {
 	ch = '\r';
-        (void) write(1, &ch, (write_size_t) 1);	/* RAW mode needs '\r', does not hurt */
+        rc = (long) write(1, &ch, (write_size_t) 1);	/* RAW mode needs '\r', does not hurt */
     }
+    if (rc == -666) gl_error("\nDon't care about compiler warning\n");
 }
 
 /******************** fairly portable part *********************************/
@@ -553,7 +553,8 @@ gl_puts(const char *buf)
     
     if (buf) {
         len = (write_size_t) strlen(buf);
-        (void) write(1, buf, len);
+        if (write(1, buf, len) < 0)
+		gl_error("\ngl_puts failed\n");
     }
 #endif
 }
@@ -567,7 +568,8 @@ gl_error(const char *const buf)
     write_size_t len = (write_size_t) strlen(buf);
 
     gl_cleanup();
-    (void) write(2, buf, len);
+    if (write(2, buf, len) < 0)
+    	exit(2);
     exit(1);
 }
 
@@ -2173,9 +2175,9 @@ gl_tab_completion(gl_tab_completion_proc proc)
 
 
 
-#ifndef _StrFindLocalPathDelim
+#ifndef My_StrFindLocalPathDelim
 static char *
-_StrRFindLocalPathDelim(const char *src)	/* TODO: optimize */
+My_StrRFindLocalPathDelim(const char *src)	/* TODO: optimize */
 {
 	const char *last;
 	int c;
@@ -2376,7 +2378,7 @@ gl_local_filename_completion_proc(const char *start, int idx)
 
 	if (dir == NULL) {
 		dirtoopen1 = NULL;
-		cp = _StrRFindLocalPathDelim(start);
+		cp = My_StrRFindLocalPathDelim(start);
 		if (cp == start) {
 			dirtoopen = LOCAL_PATH_DELIM_STR;	/* root dir */
 			filepfxoffset = 1;
@@ -2504,7 +2506,7 @@ gl_local_filename_completion_proc(const char *start, int idx)
 	if (searchHandle == NULL) {
 		dirtoopen1 = NULL;
 		dirtoopen2 = NULL;
-		cp = _StrRFindLocalPathDelim(start);
+		cp = My_StrRFindLocalPathDelim(start);
 		if (cp == start) {
 			dirtoopen = LOCAL_PATH_DELIM_STR;	/* root dir */
 			filepfxoffset = 1;
