@@ -135,8 +135,8 @@ GetScreenColumns(void)
 	osigpipe = NcSignal(SIGPIPE, SIG_IGN);
 	infp = popen(ncftpbookmarks, "r");
 	if (infp != NULL) {
-		columns = 0;
-		(void) fscanf(infp, "%d", &columns);
+		if (fscanf(infp, "%d", &columns) != 1)
+			columns = 0;
 		while (getc(infp) != EOF) {}
 		(void) pclose(infp);
 
