@@ -45,10 +45,17 @@ extern Bookmark gBm;
 extern int gSendfileInProgress;
 
 static void
+#if (defined(__GNUC__)) && (__GNUC__ >= 2)
+	__attribute__ ((noreturn))
+#endif
 Usage(void)
 {
 	FILE *fp;
 
+#ifdef __clang__
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wunreachable-code"
+#endif
 	fp = OpenPager();
 	(void) fprintf(fp, "NcFTPPut %.5s\n\n", gVersion + 11);
 	(void) fprintf(fp, "Usages:\n");
@@ -111,6 +118,10 @@ Usage(void)
 	ClosePager(fp);
 	DisposeWinsock();
 	exit(kExitUsage);
+
+#ifdef __clang__
+#pragma clang diagnostic pop
+#endif
 }	/* Usage */
 
 
@@ -262,7 +273,6 @@ main(int argc, char **argv)
 			case 'Z': case 'C':
 				(void) fprintf(stderr, "The \"-%c\" option is not valid when used with conjunction with \"-%c\".\n", c, 'b');
 				exit(kExitUsage);
-				break;
 		}
 	}
 
@@ -473,7 +483,7 @@ main(int argc, char **argv)
 	GetoptReset(&opt);
 	while ((c = Getopt(&opt, argc, argv, kGetoptOptions)) > 0) switch(c) {
 		case 'P':
-			fi.port = atoi(opt.arg);	
+			fi.port = (unsigned int) atoi(opt.arg);	
 			break;
 		case 'u':
 			(void) STRNCPY(fi.user, opt.arg);
